@@ -2,7 +2,7 @@
 # gtracks.py
 #===============================================================================
 
-"""Plot bigWig, BEDgraph, or BED signal tracks and gene annotations in a
+"""Plot bigWig, bedGraph, or BED signal tracks and gene annotations in a
 genomic region
 """
 
@@ -34,6 +34,8 @@ height = 2
 color = {color}
 min_value = 0
 max_value = {max}
+type = {plot_type}
+overlay_previous = {overlay}
 file_type = bigwig
 """
 
@@ -45,6 +47,8 @@ height = 2
 color = {color}
 min_value = 0
 max_value = {max}
+type = {plot_type}
+overlay_previous = {overlay}
 file_type = bedgraph
 """
 
@@ -117,28 +121,33 @@ def make_tracks_file(
     vlines_bed=None,
     genes=None,
     max=['auto'],
+    plot_type=['fill'],
+    overlay=False,
     color_palette=COLOR_PALETTE,
     genes_height=2,
     gene_rows=1,
     x_axis='top',
+
     bed_labels=False,
 ):
     X_AXIS_CONFIG = X_AXIS_CONFIG_FORMAT.format(x_axis)
-
+    overlay_strs = ('no',)+(len(tracks)-1)*({True: 'share-y', False: 'no'}[overlay],)
     return (
         bool(x_axis == 'top') * X_AXIS_CONFIG
         + '\n'.join(
             BIGWIG_CONFIG_FORMAT.format(
-                file=track, title=os.path.basename(track).split('.')[0],
-                color=color, max=m
+                file=track, title=os.path.basename(track).split('.')[0] if not overlay else ' ',
+                color=color, max=m, plot_type=pt, overlay=ov
             ) if track.endswith('.bw') else BEDGRAPH_CONFIG_FORMAT.format(
-                file=track, title=os.path.basename(track).split('.')[0],
-                color=color, max=m
+                file=track, title=os.path.basename(track).split('.')[0] if not overlay else ' ',
+                color=color, max=m, plot_type=pt, overlay=ov
             ) if track.endswith('.bdg') else SPACER + BED4_CONFIG_FORMAT.format(
                 file=track, title=os.path.basename(track).split('.')[0],
                 color=color, labels='true' if bed_labels else 'false'
             ) if track.endswith('.bed') else ''
-            for track, color, m in zip(tracks, cycle(color_palette), cycle(max))
+            for track, color, m, pt, ov in zip(tracks, cycle(color_palette),
+                                           cycle(max), cycle(plot_type),
+                                           overlay_strs)
         )
         + SPACER
         + bool(genes) * GENES_CONFIG_FORMAT.format(genes, genes_height, gene_rows)
@@ -224,6 +233,18 @@ def parse_arguments():
         nargs='+',
         help='max value of y-axis'
     )
+    parser.add_argument(
+        '--plot-type',
+        metavar='<{"fill","line:lw","points:ms"}>',
+        default=['fill'],
+        nargs='+',
+        help='plot type, either fill, line, or points (default: fill)'
+    )
+    parser.add_argument(
+        '--overlay',
+        action='store_true',
+        help='Overlay plots instead of stacking them'
+    )
     parser.add_argument(
         '--tmp-dir',
         metavar='<temp/file/dir>',
@@ -303,6 +324,8 @@ def main():
             vlines_bed=args.vlines_bed,
             genes=args.genes,
             max=(args.max or ['auto']),
+            plot_type=args.plot_type,
+            overlay=args.overlay,
             color_palette=args.color_palette,
             genes_height=args.genes_height,
             gene_rows=args.gene_rows,
